# Copyright (C) 2020 Sebastian Pipping <sebastian@pipping.org>
# Licensed under GPL v3 or later

from ._cli import main

if __name__ == "__main__":
    main()
